@@ -14,7 +14,7 @@ from textwrap import dedent
 from types    import SimpleNamespace
 
 from .argparse    import HelpFormatter, register_commands, register_default_command
-from .command     import build, view, deploy, remote, shell, update, check_setup, login, logout, whoami, version, debugger
+from .command     import build, view, deploy, remote, shell, update, setup, check_setup, login, logout, whoami, version, init_shell, authorization, debugger
 from .debug       import DEBUGGING
 from .errors      import NextstrainCliError
 from .util        import warn
@@ -71,11 +71,14 @@ def make_parser():
         remote,
         shell,
         update,
+        setup,
         check_setup,
         login,
         logout,
         whoami,
         version,
+        init_shell,
+        authorization,
         debugger,
     ]
 
