@@ -10,21 +10,21 @@ import requests
 import site
 import subprocess
 import sys
+from functools import partial
 from typing import Any, Callable, Mapping, List, Optional, Sequence, Tuple, Union, overload
 from typing_extensions import Literal
 from packaging.version import parse as parse_version
 from pathlib import Path
 from shlex import quote as shquote
 from shutil import which
-from sys import exit, stderr
 from textwrap import dedent, indent
 from wcmatch.glob import globmatch, GLOBSTAR, EXTGLOB, BRACE, MATCHBASE, NEGATE
 from .__version__ import __version__
-from .types import RunnerModule
+from .types import RunnerModule, RunnerTestResults
 
 
 def warn(*args):
-    print(*args, file = stderr)
+    print(*args, file = sys.stderr)
 
 
 def colored(color, text):
@@ -132,7 +132,11 @@ def check_for_new_version():
         print()
 
         if standalone_installation():
-            print("Upgrade your standalone installation by downloading a new archive from:")
+            print("Upgrade your standalone installation by running:")
+            print()
+            print(f"    {standalone_installer(newer_version)}")
+            print()
+            print("or by downloading a new archive from:")
             print()
             print(f"    {standalone_installation_archive_url(newer_version)}")
 
@@ -188,6 +192,35 @@ def standalone_installation():
     return "nextstrain-cli-is-standalone" in getattr(sys, "_xoptions", {})
 
 
+def standalone_installation_path() -> Optional[Path]:
+    """
+    Return the path of this standalone installation, if applicable.
+    """
+    if not standalone_installation():
+        return None
+
+    if not sys.executable:
+        return None
+
+    return Path(sys.executable).resolve(strict = True).parent
+
+
+def standalone_installer(version: str) -> str:
+    system = platform.system()
+
+    if system == "Linux":
+        return f"curl -fsSL --proto '=https' https://nextstrain.org/cli/installer/linux | bash -s {shquote(version)}"
+
+    elif system == "Darwin":
+        return f"curl -fsSL --proto '=https' https://nextstrain.org/cli/installer/mac | bash -s {shquote(version)}"
+
+    elif system == "Windows":
+        return 'Invoke-Expression "& { $(Invoke-RestMethod https://nextstrain.org/cli/installer/windows) } %s"' % shquote(version)
+
+    else:
+        raise RuntimeError(f"unknown system {system!r}")
+
+
 def standalone_installation_archive_url(version: str) -> str:
     machine = platform.machine()
     system = platform.system()
@@ -231,7 +264,7 @@ def fetch_latest_pypi_version(project):
     return requests.get("https://pypi.python.org/pypi/%s/json" % project).json().get("info", {}).get("version", "")
 
 
-def capture_output(argv):
+def capture_output(argv, extra_env: Mapping = {}):
     """
     Run the command specified by the argument list and return a list of output
     lines.
@@ -239,9 +272,18 @@ def capture_output(argv):
     This wrapper around subprocess.run() exists because its own capture_output
     parameter wasn't added until Python 3.7 and we aim for compat with 3.6.
     When we bump our minimum Python version, we can remove this wrapper.
+
+    If an *extra_env* mapping is passed, the provided keys and values are
+    overlayed onto the current environment.
     """
+    env = os.environ.copy()
+
+    if extra_env:
+        env.update(extra_env)
+
     result = subprocess.run(
         argv,
+        env    = env,
         stdout = subprocess.PIPE,
         check  = True)
 
@@ -287,7 +329,7 @@ def exec_or_return(argv: List[str], extra_env: Mapping = {}) -> int:
             warn("Error running %s: %s" % (argv, error))
             return 1
         else:
-            exit(process.returncode)
+            sys.exit(process.returncode)
 
 
 def runner_name(runner: RunnerModule) -> str:
@@ -297,6 +339,60 @@ def runner_name(runner: RunnerModule) -> str:
     return module_basename(runner).replace("_", "-")
 
 
+def runner_module(name: str) -> RunnerModule:
+    """
+    Converts a string *name* into a :py:cls:`RunnerModule`.
+
+    *name* is case-insensitive and underscores, hyphens, or spaces may be used
+    to separate words.  Internally, they're normalized to hyphens and the whole
+    string is lowercased.
+
+    ``native`` is accepted as an alias for ``ambient``.
+
+    Raises a :py:exc:`ValueError` if *name* is unknown.
+
+    >>> runner_module("docker") # doctest: +ELLIPSIS
+    <module 'cli.runner.docker' from '...'>
+
+    >>> runner_module("AWS-Batch") # doctest: +ELLIPSIS
+    <module 'cli.runner.aws_batch' from '...'>
+
+    >>> runner_module("AWS Batch") # doctest: +ELLIPSIS
+    <module 'cli.runner.aws_batch' from '...'>
+
+    >>> runner_module("native") # doctest: +ELLIPSIS
+    <module 'cli.runner.ambient' from '...'>
+
+    >>> runner_module("invalid")
+    Traceback (most recent call last):
+        ...
+    ValueError: invalid runtime name: 'invalid'; valid names are: 'docker', 'conda', 'ambient', 'aws-batch'
+
+    >>> runner_module("Invalid Name")
+    Traceback (most recent call last):
+        ...
+    ValueError: invalid runtime name: 'Invalid Name' (normalized to 'invalid-name'); valid names are: 'docker', 'conda', 'ambient', 'aws-batch'
+    """
+    # Import here to avoid circular import
+    from .runner import all_runners_by_name
+
+    normalized_name = re.sub(r'(_|\s+)', '-', name).lower()
+
+    # Accept "native" as an alias for "ambient" for backwards compatibility
+    if normalized_name == "native":
+        normalized_name = "ambient"
+
+    try:
+        return all_runners_by_name[normalized_name]
+    except KeyError as err:
+        valid_names = ", ".join(map(repr, all_runners_by_name))
+
+        if name != normalized_name:
+            raise ValueError(f"invalid runtime name: {name!r} (normalized to {normalized_name!r}); valid names are: {valid_names}") from err
+        else:
+            raise ValueError(f"invalid runtime name: {name!r}; valid names are: {valid_names}") from err
+
+
 def runner_help(runner: RunnerModule) -> str:
     """
     Return a brief description of a runner module, suitable for help strings.
@@ -461,3 +557,41 @@ def glob_match(path: Union[str, Path], patterns: Union[str, Sequence[str]]) -> b
     Implemented with with :func:`wcmatch.glob.globmatch`.
     """
     return globmatch(path, patterns, flags = GLOBSTAR | BRACE | EXTGLOB | MATCHBASE | NEGATE)
+
+
+def runner_tests_ok(tests: RunnerTestResults) -> bool:
+    """
+    Returns True iff none of a runner's ``test_setup()`` results failed.
+    """
+    return False not in [result for test, result in tests]
+
+
+def print_runner_tests(tests: RunnerTestResults):
+    """
+    Prints a formatted version of the return value of a runner's
+    ``test_setup()``.
+    """
+    success = partial(colored, "green")
+    failure = partial(colored, "red")
+    warning = partial(colored, "yellow")
+    unknown = partial(colored, "gray")
+
+    # XXX TODO: Now that there are special values other than True/False, these
+    # should probably become an enum or custom algebraic type or something
+    # similar.  That will cause a cascade into the test_setup() producers
+    # though, which I'm going to punt on for now.
+    #  -trs, 4 Oct 2018
+    status = {
+        True:  success("✔ yes"),
+        False: failure("✘ no"),
+        None:  warning("⚑ warning"),
+        ...:   unknown("? unknown"),
+    }
+
+    for description, result in tests:
+        # Indent subsequent lines of any multi-line descriptions so it
+        # lines up under the status marker.
+        formatted_description = \
+            remove_prefix("  ", indent(description, "  "))
+
+        print(status.get(result, str(result)) + ":", formatted_description)
